@@ -46,7 +46,9 @@ _assuan_sysutils_blurb (void)
     "\n\n"
     "This is Libassuan " PACKAGE_VERSION " - The GnuPG IPC Library\n"
     "Copyright 2000, 2002, 2003, 2004, 2007, 2008, 2009,\n"
-    "          2010, 2011 Free Software Foundation, Inc.\n"
+    "          2010, 2011, 2013 Free Software Foundation, Inc.\n"
+    "\n"
+    "(" BUILD_REVISION " " BUILD_TIMESTAMP ")\n"
     "\n\n";
   return blurb;
 }
